## Architecture Design

Robyn is a Python web server that uses the tokio runtime. Below is a little outdated architecture of robyn but it still serves the purpose.

*Latest architecture diagram will be updated within a few weeks*

![Diagram](https://i.ibb.co/cNV4DJX/image.png)

![Diagram of the final Architecture](https://i.ibb.co/GHwTTqk/Untitled-2021-02-25-0125-1.png)
